@@ -1,4 +1,4 @@
-from .types import (
+from .ntypes import (
     t_delete,
     t_size,
     t_job,
@@ -15,6 +15,7 @@ from .runner.env_var import n_env
 import pandas as pd
 import traceback
 import ipykernel
+import subprocess
 import requests
 import base64
 import copy
@@ -85,7 +86,7 @@ class Manager:
 
     def set_runner_mode(self):
         try:
-            r = requests.get(f"{n_env.api}/{t_env}", headers=self.headers)
+            r = requests.get(f"{n_env.api}/{t_env}", headers=self.headers, timeout=2)
             r.raise_for_status()
         except Exception:
             n_env.remote_mode = not n_env.remote_mode
@@ -140,29 +141,47 @@ class Manager:
         if self.is_production():
             return os.path.join(n_env.server_root, n_env.current.get("path"))
         try:
-            connection_file = os.path.basename(ipykernel.get_connection_file())
-            kernel_id = connection_file.split("-", 1)[1].split(".")[0]
-            if enterprise_gateway:
-                kernel_id = connection_file.split("-", 1)[1].split("_")[0]
             notebooks = self.running_notebooks()
-            for notebook in notebooks:
-                if kernel_id in notebook["kernel_id"]:
-                    return os.path.join(n_env.server_root, notebook["path"])
+            try:
+                connection_file = os.path.basename(ipykernel.get_connection_file())
+                kernel_id = connection_file.split("-", 1)[1].split(".")[0]
+                if enterprise_gateway:
+                    kernel_id = connection_file.split("-", 1)[1].split("_")[0]
+                for notebook in notebooks:
+                    if kernel_id in notebook["kernel_id"]:
+                        return os.path.join(n_env.server_root, notebook["path"])
+            except Exception:
+                process_id = os.getpid()
+                for notebook in notebooks:
+                    if process_id in notebook["process_ids"]:
+                        return os.path.join(n_env.server_root, notebook["path"])
         except Exception as e:
             tb = traceback.format_exc()
             print("notebook_path", e, tb)
         return None
 
+    def __get_process_ids(self, name):
+        try:
+            child = subprocess.Popen(
+                ["pgrep", "-f", name], stdout=subprocess.PIPE, shell=False
+            )
+            response = child.communicate()[0]
+            return [int(pid) for pid in response.split()]
+        except Exception:
+            return []
+
     def running_notebooks(self):
         try:
             base_url = f"{n_env.user_url}/api/sessions"
             req = requests.get(url=base_url, headers=self.headers)
             req.raise_for_status()
             sessions = req.json()
+            sessions = filter(lambda item: "notebook" in item["type"], sessions)
             notebooks = [
                 {
                     "kernel_id": notebook["kernel"]["id"],
                     "path": notebook["notebook"]["path"],
+                    "process_ids": self.__get_process_ids(notebook["kernel"]["id"]),
                 }
                 for notebook in sessions
             ]
@@ -178,7 +197,10 @@ class Manager:
 
     def get_path(self, path):
         if path is not None:
-            return os.path.abspath(os.path.join(os.getcwd(), path))
+            base_path = os.getcwd()
+            if self.is_production():
+                base_path = base_path.replace(n_env.path_naas_folder, "")
+            return os.path.abspath(os.path.join(base_path, path))
         else:
             return self.notebook_path()
 
